import { defineNuxtModule, createResolver, addServerHandler, addPrerenderRoutes, addTemplate } from '@nuxt/kit';

const module = defineNuxtModule({
  meta: {
    name: "nuxt-module-feed",
    configKey: "feed"
  },
  defaults: {
    sources: []
  },
  setup(options, nuxt) {
    const resolver = createResolver(import.meta.url);
    const feedOptions = {};
    options.sources.forEach((source) => {
      addServerHandler({
        route: source.path,
        handler: resolver.resolve("./runtime/routes/feed"),
        method: "get"
      });
      if (nuxt.options._generate) {
        addPrerenderRoutes([source.path]);
      }
      feedOptions[source.path] = source;
    });
    nuxt.options.alias["#feed"] = addTemplate({
      filename: "feedOptions.mjs",
      write: true,
      getContents: () => `export default ${JSON.stringify(feedOptions, null, 2)}`
    }).dst || "";
  }
});

export { module as default };
